@@ -18,12 +18,14 @@ public:
     QRegExp urlPattern() const;
     bool urlSupported(const QUrl &url) const;
     void checkUrl(const QUrl &url);
-    void getDownloadUrl(const QUrl &url);
+    void getDownloadRequest(const QUrl &url);
     inline bool loginSupported() const { return true; }
     void login(const QString &username, const QString &password);
     inline bool recaptchaRequired() const { return true; }
-    inline QString recaptchaKey() const { return m_captchaId; }
+    inline QString recaptchaKey() const { return m_captchaKey; }
     inline QString recaptchaServiceName() const { return QString("Uloz"); }
+    inline int maximumConnections() const { return m_connections; }
+    bool cancelCurrentOperation();
 
 public slots:
     void submitCaptchaResponse(const QString &challenge, const QString &response);
@@ -34,13 +36,17 @@ private slots:
     void onWebPageDownloaded();
     void onCaptchaSubmitted();
 
+signals:
+    void currentOperationCancelled();
+
 private:
     QUrl m_url;
-    QString m_captchaId;
     QString m_captchaKey;
+    QString m_token;
     QString m_timestamp;
     QString m_cid;
     QString m_sign;
+    int m_connections;
 };
 
 #endif // ULOZ_H
